@@ -60,4 +60,14 @@ class Snapshot():
             cmd = Command.SELECT_ALL_WHERE.substitute(table=table, condition=self.id + "=" + str(id))
             r = self.dbCursor.execute(cmd).fetchall()
             result.append(r[0])
-        return result
\ No newline at end of file
+        return result
+    
+    def getRowsForTable(self, table):
+        cmd = Command.SELECT_ALL.substitute(table=table)
+        rows = self.dbCursor.execute(cmd).fetchall()
+        return rows
+    
+    def getRowCountForTable(self, table):
+        cmd = Command.COUNT_ROWS.substitute(table=table)
+        count = self.dbCursor.execute(cmd).fetchall()
+        return count[0][0]
\ No newline at end of file
